from distutils.core import setup

setup(
		name         = 'zcz',
		version      = '1.1.0',
		py_modules   = ['zhoufirst'],
		author       = 'changzhiZhou',
		author_email = '1059482037@qq.com',
		url          = 'http://baidu.com',
		description  = 'A simple printer of nested lists'
		)